===============
Envío de correo
===============

Este módulo permite dar de alta servidores para el envío de correos
electrónicos mediante el protocolo SMTP. 

Este módulos sirve de base para que otros módulos puedan enviar correos
electrónicos, como por ejemplo el módulo *Plantillas correo electrónico*.
